
# ZA GENERISANJE MULTIVARIJATNE NORMALNE RASPODELE:
require(MASS, quietly=TRUE)

regConst <- function(min=1, max=10, a=1, b=0.5, it=20, m=0, s=1) {
##################################################################
# min -> minimum za varijablu X
# max -> maksimum za varijablu X
# a   -> odsecak na Y-osi
# b   -> nagib regresione funkcije
# it  -> broj pokusaja (iteracija)
# m   -> aritmeticka sredina za gresku (epsilon)
# s   -> standardna devijacija za gresku (epsilon)
##################################################################
	x <- seq(min, max)
	y <- a + b * x
	yMIN <- min(y)
	yMAX <- max(y)
	plot(x, y, t='l', col='red', lwd=4,
		xlim=c(min-2,max+2), ylim=c(yMIN-2,yMAX+2))
	for (j in 1:it) {
		scan(n=1)
		epsilon <- rnorm(n=length(x), mean=m, sd=s)
		yTMP <- lm(y+epsilon ~ x)
		abline(yTMP, col=j, lwd=1)
	}
}

regVar <- function(min=1, max=10, a=1, b=0.5, it=100, m=0, s=0.1, g=0.1) {
##########################################################################
# min -> minimum za varijablu X
# max -> maksimum za varijablu X
# a   -> odsecak na Y-osi
# b   -> nagib regresione funkcije
# it  -> broj pokusaja (iteracija)
# m   -> aritmeticka sredina za gresku (epsilon)
# s   -> standardna devijacija za gresku (epsilon)
# g   -> koeficijent prirastaja greske (epsilon) u funkciji X
##########################################################################
	x <- seq(min, max)
	y <- a + b * x
	yMIN <- min(y)
	yMAX <- max(y)
	plot(x, y, t='l', col='red', lwd=4,
		xlim=c(min-2,max+2), ylim=c(yMIN-2,yMAX+2))
	for (j in 1:it) {
		epsilon <- rep(0, ncol=length(x))
		for (i in 1:length(x)) {
			epsilon[i] <- rnorm(n=1, mean=m, sd=s+g*x[i])
		}
		yTMP <- y + epsilon
		points(jitter(x), yTMP, lwd=1, pty='.')
	}
}

regCorr <- function(n=200, m=c(0,0), r=0.3, it=10) {
####################################################
# n   -> velicina uzorka
# m   -> aritmeticke sredine za dve varijable
# r   -> koeficijent korelacije
# it  -> broj pokusaja (iteracija)
####################################################
	for (j in 1:it) {
		x <- mvrnorm(n, mu=m, Sigma=cbind(c(1,r), c(r,1)))
		x1MIN <- min(x[,1])
		x1MAX <- max(x[,1])
		x2MIN <- min(x[,2])
		x2MAX <- max(x[,2])
		plot(x[,1], x[,2], t='p', lwd=1, pty='.',
			xlim=c(x1MIN-2,x1MAX+2), ylim=c(x2MIN-2,x2MAX+2))
		regLine <- lm(x[,2] ~ x[,1])
		abline(regLine, col='blue', lwd=2)
		text(x1MIN-1, x2MAX, paste('b = ',
			round(regLine$coefficients[[2]],3), sep=''))
		text(x1MIN-1, x2MAX+1, paste('a = ',
			round(regLine$coefficients[[1]],3), sep=''))
		scan(n=1)
	}
}


